@@ -21,7 +21,7 @@ def _mod_check(value: str):
 
 
 @validator
-def iban(value: str):
+def iban(value: str, /):
     """Return whether or not given value is a valid IBAN code.
 
     Examples:
@@ -31,7 +31,8 @@ def iban(value: str):
         # Output: ValidationFailure(func=iban, ...)
 
     Args:
-        value: IBAN string to validate.
+        value:
+            IBAN string to validate.
 
     Returns:
         (Literal[True]):
@@ -41,4 +42,8 @@ def iban(value: str):
 
     > *New in version 0.8.0*
     """
-    return re.match(r"^[A-Z]{2}[0-9]{2}[A-Z0-9]{11,30}$", value) and _mod_check(value)
+    return (
+        (re.match(r"^[A-Z]{2}[0-9]{2}[A-Z0-9]{11,30}$", value) and _mod_check(value))
+        if value
+        else False
+    )
